pub fn channel<T, const CAP: usize>() -> (SpscSender<T, CAP>, SpscReceiver<T, CAP>)Expand description
Pairs a ring with its two ends for handing to separate threads.
pub fn channel<T, const CAP: usize>() -> (SpscSender<T, CAP>, SpscReceiver<T, CAP>)Pairs a ring with its two ends for handing to separate threads.